@@ -245,6 +245,8 @@ struct _YelpWindowPriv {
     gchar          *find_string;
     GtkAction      *find_next_menu;
     GtkAction      *find_prev_menu;
+    GtkToolItem    *find_sep;
+    GtkToolItem    *find_not_found;
 
     /* Open Location */
     GtkWidget      *location_dialog;
@@ -277,7 +279,6 @@ struct _YelpWindowPriv {
     gulong          finish_handler;
 
     gint            toc_pause;
-    guint           html_idle_handle;
 
     GtkActionGroup *action_group;
     GtkUIManager   *ui_manager;
@@ -878,7 +879,7 @@ page_request_cb (YelpDocument       *document,
 	data->window = window;
 	data->page = (YelpPage *) func_data;
 
-	window->priv->html_idle_handle = g_idle_add ((GSourceFunc)window_write_html, data);
+	window_write_html (data);
 
 	window->priv->current_request = -1;
 	yelp_page_free ((YelpPage *) func_data);
@@ -931,10 +932,6 @@ window_setup_window (YelpWindow *window, YelpRrnType type,
 	window->priv->base_uri = tmp;
     }
 
-    if (window->priv->html_idle_handle) {
-	g_source_remove (window->priv->html_idle_handle);
-	window->priv->html_idle_handle = 0;
-    }
 
     window_set_loading (window);
 
@@ -999,6 +996,7 @@ yelp_window_load (YelpWindow *window, const gchar *uri)
     history_clear_forward (window);
 
     type = yelp_uri_resolve (trace_uri, &real_uri, &frag_id);
+
     if (type == YELP_RRN_TYPE_ERROR) {
 	gchar *message = g_strdup_printf (_("The requested URI \"%s\" is invalid"), trace_uri);
 	window_error (window, _("Unable to load page"), message, FALSE);
@@ -1034,6 +1032,8 @@ yelp_window_load (YelpWindow *window, const gchar *uri)
 	    break;
 	case YELP_RRN_TYPE_SEARCH:
 	    doc = yelp_search_new (&real_uri[14]); /* to remove x-yelp-search:*/
+	    priv->base_uri = g_strdup ("file:///fakefile");
+
 	    break;
 	case YELP_RRN_TYPE_HTML:
 	case YELP_RRN_TYPE_XHTML:
@@ -1041,18 +1041,18 @@ yelp_window_load (YelpWindow *window, const gchar *uri)
 	    break;
 	case YELP_RRN_TYPE_EXTERNAL:
 	    {
-		gchar *stdout = NULL;
-		gchar *stderr = NULL;
+		gchar *str_stdout = NULL;
+		gchar *str_stderr = NULL;
 		gchar *cmd = NULL;
 		gint status = 0;
 		GError *error = NULL;
 		cmd = g_strdup_printf ("gnome-open %s", uri);
-		if (!g_spawn_command_line_sync (cmd, &stdout, &stderr, &status, &error)) {
+		if (!g_spawn_command_line_sync (cmd, &str_stdout, &str_stderr, &status, &error)) {
 		    g_free (error);
 		    error = NULL;
 		    g_free (cmd);
 		    cmd = g_strdup_printf ("xdg-open %s", uri);
-		    if (!g_spawn_command_line_sync (cmd, &stdout, &stderr, &status, &error)) {
+		    if (!g_spawn_command_line_sync (cmd, &str_stdout, &str_stderr, &status, &error)) {
 			window_error(window, _("Error executing \"gnome-open\""), error->message, FALSE);
 			return;
 		    }
@@ -1072,7 +1072,7 @@ yelp_window_load (YelpWindow *window, const gchar *uri)
     if (doc) {
 	gboolean need_hist = FALSE;
 	if (!frag_id)
-	    frag_id = g_strdup ("index");
+	  frag_id = g_strdup ("x-yelp-index");
 
 	if (priv->current_document || (priv->current_type == YELP_RRN_TYPE_HTML ||
 				       priv->current_type == YELP_RRN_TYPE_XHTML))
@@ -1167,7 +1167,7 @@ search_activated (GtkAction *action,
 	spaces = strchr (search_terms, ' ');
 	while (spaces) {
 	    count++;
-	    spaces = strchr (search_terms, ' ');
+	    spaces = strchr (spaces+1, ' ');
 	}
 	if (count == 1) {
 	    uri = g_strdup (search_terms);
@@ -1436,6 +1436,18 @@ window_populate_find (YelpWindow *window, GtkWidget *find_bar)
 		      window);
     gtk_toolbar_insert (GTK_TOOLBAR (find_bar), priv->find_prev, -1);
 
+    priv->find_sep = gtk_separator_tool_item_new ();
+    gtk_toolbar_insert (GTK_TOOLBAR (find_bar), priv->find_sep, -1);
+
+    label = gtk_label_new (_("Phrase not found"));
+    priv->find_not_found = gtk_tool_item_new ();
+
+    gtk_tool_item_set_expand (priv->find_not_found, TRUE);
+    gtk_container_add (GTK_CONTAINER (priv->find_not_found), label);
+    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+    gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
+    gtk_toolbar_insert (GTK_TOOLBAR (find_bar), priv->find_not_found, -1);    
+
     item = gtk_separator_tool_item_new ();
     gtk_tool_item_set_expand (item, TRUE);
     gtk_separator_tool_item_set_draw (GTK_SEPARATOR_TOOL_ITEM (item), FALSE);
@@ -2114,6 +2126,8 @@ window_find_cb (GtkAction *action, YelpWindow *window)
     debug_print (DB_FUNCTION, "entering\n");
 
     gtk_widget_show_all (priv->find_bar);
+    gtk_widget_hide (GTK_WIDGET (priv->find_not_found));
+    gtk_widget_hide (GTK_WIDGET (priv->find_sep));
     gtk_widget_grab_focus (priv->find_entry);
     window_find_entry_changed_cb (GTK_EDITABLE (priv->find_entry), window);
 }
@@ -2521,8 +2535,12 @@ window_find_entry_changed_cb (GtkEditable *editable,
 	window_find_buttons_set_sensitive (window, FALSE, FALSE);
     else
 	if (found) {
+	    gtk_widget_hide (GTK_WIDGET (priv->find_sep));
+	    gtk_widget_hide (GTK_WIDGET (priv->find_not_found));
 	    window_find_buttons_set_sensitive (window, FALSE, TRUE);
 	} else {
+	    gtk_widget_show_all (GTK_WIDGET (priv->find_sep));
+	    gtk_widget_show_all (GTK_WIDGET (priv->find_not_found));
 	    window_find_buttons_set_sensitive (window, TRUE, TRUE);
 	}
  
@@ -2641,7 +2659,6 @@ window_write_html (YelpLoadData *data)
 	yelp_html_write (html, contents, read);
     } while (read == BUFFER_SIZE);
     yelp_html_close (html);
-    data->window->priv->html_idle_handle = 0;
     return FALSE;
 }
 
